package com.chelvc.cloud.vehicle.client;

import java.util.List;
import java.util.Map;

import com.chelvc.cloud.vehicle.client.constant.MerchantStatus;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDetailDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantRankDTO;
import com.chelvc.cloud.vehicle.client.param.*;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 商家业务接口
 *
 * @author Woody
 * @date 2023/5/4
 */
@FeignClient("vehicle")
public interface MerchantClient {
    /**
     * 获取附近商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    @GetMapping("/merchant/listNearbyMerchants")
    List<MerchantDTO> listNearbyMerchants(@SpringQueryMap LocationQueryParam param, @RequestParam("size") int size);


    /**
     * @param param 查询参数
     * @return 商家信息分页列表
     */
    @GetMapping("/merchant/indexMerchantPaging")
    Pagination<MerchantDTO> indexMerchantPaging(@SpringQueryMap LocationQueryPagingParam param);

    /**
     * 获取推荐商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    @GetMapping("/merchant/listRecommendMerchants")
    List<MerchantDTO> listRecommendMerchants(@SpringQueryMap LocationQueryParam param, @RequestParam("size") int size);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    @GetMapping("/merchant/listSimpleMerchants")
    List<MerchantDTO> listSimpleMerchants(@SpringQueryMap MerchantQueryParam param);


    /**
     * 分页查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    @GetMapping("/merchant/merchantPagingList")
    Pagination<MerchantDTO> merchantPagingList(@SpringQueryMap MerchantQueryParamPaging param);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @return 商家详情
     */
    @GetMapping("/merchant/getMerchantDetail")
    MerchantDetailDTO getMerchantDetail(@RequestParam("id") Long id);

    /**
     * 获取商家详情
     *
     * @param id    商家ID
     * @param param 查询参数
     * @return 商家详情
     */
    @GetMapping("/merchant/queryMerchantDetail")
    MerchantDetailDTO queryMerchantDetail(@RequestParam("id") Long id, @SpringQueryMap LocationQueryParam param);

    /**
     * 新增商家
     *
     * @param param 新增参数
     * @return 商家主键
     */
    @PostMapping("/merchant/addMerchant")
    Long addMerchant(@RequestBody MerchantModifyParam param);

    /**
     * 修改商家
     *
     * @param id    商家主键
     * @param param 修改参数
     */
    @PutMapping("/merchant/updateMerchant")
    void updateMerchant(@RequestParam("id") Long id, @RequestBody MerchantModifyParam param);

    /**
     * 删除商家
     *
     * @param id 商家主键
     */
    @DeleteMapping("/merchant")
    void deleteMerchant(@RequestParam("id") Long id);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家分页信息
     */
    @GetMapping("/merchant/getMerchantPaging")
    Pagination<MerchantDTO> getMerchantPaging(@SpringQueryMap MerchantPagingParam param);

    /**
     * 查询商家信息
     *
     * @param id 商家主键
     * @return 商家信息
     */
    @GetMapping("/merchant/getMerchant")
    MerchantDTO getMerchant(@RequestParam("id") Long id);

    /**
     * 获取商家信息
     *
     * @return
     */
    @GetMapping("/merchant/getMerchantIdsByUserId")
    List<MerchantDTO> getMerchantIdsByUserId();

    /**
     * 查询商家排名
     *
     * @param param
     * @param userId
     * @return
     */
    @GetMapping("/merchant/listUserRankMerchants")
    List<MerchantRankDTO> listUserRankMerchants(@SpringQueryMap MerchantRankParam param,
                                                @RequestParam("userId") Long userId);

    /**
     * 后台查询商家排名
     *
     * @param param
     * @return
     */
    @GetMapping("/merchant/listRankMerchants")
    List<MerchantRankDTO> listRankMerchants(@SpringQueryMap MerchantRankParam param);

    /**
     * 我的购物车列表
     *
     * @param param
     * @return
     */
    @GetMapping("/merchant/getUserMineCartPaging")
    Pagination<MerchantDTO> getUserMineCartPaging(@SpringQueryMap OmsCartItemPagingParam param);

    /**
     * 更改商家得营业状态
     *
     * @param merchantId     商家ID
     * @param businessStatus 营业状态
     */
    @GetMapping("/merchant/updateMerchantBusinessStatus")
    void updateMerchantBusinessStatus(@RequestParam("merchantId") Long merchantId,
                                      @RequestParam("businessStatus") String businessStatus);

    /**
     * 获取商家营业状况
     *
     * @return
     */
    @GetMapping("/merchant/operatConditions")
    Map<String, Object> operatConditions();

    /**
     * 经营报表
     *
     * @return 经营报表信息
     */
    @GetMapping("/merchant/operatReport")
    List<Map<String, Object>> operatReport(@SpringQueryMap ReportModifyParam param);

    /**
     * 商家审核
     *
     * @param id
     * @param status
     */
    @PostMapping("/merchant/merchantAudit")
    void merchantAudit(@RequestParam("id") Long id, @RequestParam("status") MerchantStatus status);


    /**
     * 获取商家入驻统计
     *
     * @return
     */
    @GetMapping("/merchant/getMerchantReport")
    List<Map<String, Object>> getMerchantReport(@SpringQueryMap ReportModifyParam param);


    /**
     * 获取商家入驻统计
     *
     * @return
     */
    @GetMapping("/merchant/getMerchantReportCount")
    Map<String, Object> getMerchantReportCount(@SpringQueryMap ReportModifyParam param);

    /**
     * 子商户入网回调接口
     *
     */
    @PostMapping("/merchant/apply/notify")
    void merchantApplyNotify(@RequestBody SxyNotifyParam param);
}



