package com.chelvc.cloud.vehicle.server.controller;

import java.util.List;
import java.util.Map;

import com.chelvc.cloud.vehicle.client.constant.GoodsStatus;
import com.chelvc.cloud.vehicle.client.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.client.dto.GoodsDetailDTO;
import com.chelvc.cloud.vehicle.client.param.GoodsModifyParam;
import com.chelvc.cloud.vehicle.client.param.GoodsPagingParam;
import com.chelvc.cloud.vehicle.client.param.GoodsQueryParam;
import com.chelvc.cloud.vehicle.server.service.GoodsService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商品业务接口
 *
 * @author Woody
 * @date 2023/8/6
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class GoodsController {

    private final GoodsService goodsService;

    /**
     * 获取商品详情
     *
     * @param id 商品ID
     * @return 商品详情
     */
    @GetMapping("/goods/getGoodsDetail")
    public GoodsDetailDTO getGoodsDetail(@RequestParam("id") Long id) {
        return goodsService.getGoodsDetail(id);
    }

    /**
     * 查询商家商品
     *
     * @param merchantId 商家ID
     * @param param      查询参数
     * @return 商品列表
     */
    @GetMapping("/goods/listMerchantSimpleGoods")
    public List<GoodsDTO> listMerchantSimpleGoods(@RequestParam("merchantId") Long merchantId,
                                                  @SpringQueryMap GoodsQueryParam param) {
        return goodsService.listMerchantSimpleGoods(merchantId, param);
    }


    /**
     * 新增商品
     *
     * @param param 新增参数
     * @return 商品主键
     */
    @PostMapping("/goods/addGoods")
    public Long addGoods(@RequestBody GoodsModifyParam param) {
        return goodsService.addGoods(param);
    }

    /**
     * 修改商品
     *
     * @param id    商品主键
     * @param param 修改参数
     */
    @PutMapping("/goods/updateGoods")
    public void updateGoods(@RequestParam("id") Long id, @RequestBody GoodsModifyParam param) {
        goodsService.updateGoods(id, param);
    }

    /**
     * 删除商品
     *
     * @param id 商品主键
     */
    @DeleteMapping("/goods")
    public void deleteGoods(@RequestParam("id") Long id) {
        goodsService.deleteGoods(id);
    }

    /**
     * 查询商品
     *
     * @param param 查询参数
     * @return 商品分页信息
     */
    @GetMapping("/goods/getGoodsPaging")
    public Pagination<GoodsDTO> getGoodsPaging(GoodsPagingParam param) {
        return goodsService.getGoodsPaging(param);
    }

    /**
     * 修改商品状态
     *
     * @param ids    商品ID集合
     * @param status 商品状态
     */
    @PutMapping("/goods/updateGoodsStatus")
    public void updateGoodsStatus(@RequestParam("ids") List<Long> ids, @RequestParam("status") GoodsStatus status) {
        goodsService.updateGoodsStatus(ids, status);
    }

    /**
     * 商家端商品管理
     *
     * @param param
     * @return
     */
    @GetMapping("/goods/getMerchantGoodsList")
    public List<GoodsDTO> getMerchantGoodsList(GoodsQueryParam param) {
        return goodsService.getMerchantGoodsList(param);
    }

    /**
     * 获取商品的订单量以及交易金额
     *
     * @return
     */
    @GetMapping("/goods/getGoodsAmount")
    public List<Map<String, Object>> getGoodsAmount() {
        return goodsService.getGoodsAmount();
    }
}
